clear all, clc, close all

load('reactions.mat')
load('species.mat')

figure (1)

% Find internal energy for each species
E_i = str2double(erase(species{2},'eV'));
% N2v1 index in species.csv
N2v1_index = find(strcmp(species{1},'N2v1'));
% N2 energy levels
% V Laporta et al Plasma Sources Sci. Technol. 23 (2014) 065002
% https://iopscience.iop.org/article/10.1088/0963-0252/23/6/065002/pdf
E_N2v = [0; E_i(N2v1_index:N2v1_index+56); 9.748];

Tg = [300 500];

% Mario Capitelli. Book review: Nonequilibrium Vibrational Kinetics. Springer-Verlag Berlin, Heidelberg, 1986 (P104).
% https://link.springer.com/book/10.1007/978-3-642-48615-9
% Chemical Physics, Volume 43, Issue 3, 1 November 1979, Pages 395-401
% https://www.sciencedirect.com/science/article/pii/0301010479852076
w_Bil79_f1 = [1:1:9 20];
rate_Bil79_f1 = [0.8 1.8 3.1 5.0 7.4 11 16 26 38 1600].*1e-21.*1e-6;
w_Bil79_f2 = [1:1:9 20];
rate_Bil79_f2 = [0.4 0.9 1.7 3.0 4.7 7.1 10 15 22 780].*1e-19.*1e-6;

% Mario Capitelli. Book review: Nonequilibrium Vibrational Kinetics. Springer-Verlag Berlin, Heidelberg, 1986 (P104).
% https://link.springer.com/book/10.1007/978-3-642-48615-9
% M. Capitelli et al, Chemical Physics Volume 52, Issue 3, November 1980, Pages 299-304 
% https://doi.org/10.1016/0301-0104(80)85233-5
w_Cap80_f1 = [30 40];
rate_Cap80_f1 = [6.9 240].*1e-17.*1e-6;
w_Cap80_f2 = [30 40];
rate_Cap80_f2 = [9.2 220].*1e-16.*1e-6;

rate_k5_f1 = [];
w_list5_f1 = [];
for i =1:length(reactions{4})
    if strcmp(reactions{3}{i},'N2N2VTSSH_Gue19')==1
        [rateCoeff,v] = N2N2VTsfHO(Tg(1),reactions{4}{i},E_N2v);
        
        rate_k5_f1 = [rate_k5_f1 rateCoeff];
        w_list5_f1 = [w_list5_f1 v];
        
    end
end

rate_k5_f2 = [];
w_list5_f2 = [];
for i =1:length(reactions{4})
    if strcmp(reactions{3}{i},'N2N2VTSSH_Gue19')==1
        [rateCoeff,v] = N2N2VTsfHO(Tg(2),reactions{4}{i},E_N2v);
        
        rate_k5_f2 = [rate_k5_f2 rateCoeff];
        w_list5_f2 = [w_list5_f2 v];
        
    end
end

rate_k6_f1 = [];
w_list6_f1 = [];
for i =1:length(reactions{4})
    if strcmp(reactions{3}{i},'N2N2VTSSH_Gue19')==1
        [rateCoeff,v] = N2N2VT_Richards38(Tg(1),reactions{4}{i},E_N2v);
        
        rate_k6_f1 = [rate_k6_f1 rateCoeff];
        w_list6_f1 = [w_list6_f1 v];
        
    end
end

rate_k6_f2 = [];
w_list6_f2 = [];
for i =1:length(reactions{4})
    if strcmp(reactions{3}{i},'N2N2VTSSH_Gue19')==1
        [rateCoeff,v] = N2N2VT_Richards38(Tg(2),reactions{4}{i},E_N2v);
        
        rate_k6_f2 = [rate_k6_f2 rateCoeff];
        w_list6_f2 = [w_list6_f2 v];
        
    end
end


m1=plot(w_Bil79_f1,rate_Bil79_f1,'o','Color','k','MarkerSize',6)
set(m1, 'markerfacecolor', get(m1, 'color'));
hold on
m1=plot(w_Cap80_f1,rate_Cap80_f1,'^','Color','k','MarkerSize',7)
set(m1, 'markerfacecolor', get(m1, 'color'));
hold on
plot(w_list5_f1,rate_k5_f1,'k-','LineWidth',2)
hold on
plot(w_list6_f1,rate_k6_f1,'k--','LineWidth',2)
hold on

m1=plot(w_Bil79_f2,rate_Bil79_f2,'o','Color','r','MarkerSize',6)
set(m1, 'markerfacecolor', get(m1, 'color'));
hold on
m1=plot(w_Cap80_f2,rate_Cap80_f2,'^','Color','r','MarkerSize',7)
set(m1, 'markerfacecolor', get(m1, 'color'));
hold on
plot(w_list5_f2,rate_k5_f2,'r-','LineWidth',2)
hold on
plot(w_list6_f2,rate_k6_f2,'r--','LineWidth',2)
hold on

xlim([0 60])
xticks(0:5:60)
xlabel('N_2 vibrational level (v)')

set(gca, 'YScale', 'log')
% ylim([1e-29 1e-17])
% yticks([1e-29 1e-27 1e-25 1e-23 1e-21 1e-19 1e-17])
ylim([1e-30 1e-16])
yticks([1e-30 1e-28 1e-26 1e-24 1e-22 1e-20 1e-18 1e-16])
ylabel('k_{v,v-1} (m^{3}/s)')

% lgd4 = legend('Billing {\itet al}','sfHO','Richards {\itet al}','Location','Northwest')
lgd4 = legend('Billing {\itet al}','Capitelli','sfHO','ffSC','Location','Northwest')
lgd4.FontSize = 15;

set(gca,'FontSize',15)

text(0.2,0.1,'N_2(v) + N_2(v=0) \rightarrow N_2(v-1) + N_2(v=0) ','Units','normalized','Color',[0 0.5 0],'FontSize',12)
text(0.5,0.9,'500 K','Units','normalized','Color','r','FontSize',12)
text(0.5,0.8,'300 K','Units','normalized','Color','k','FontSize',12)

text(0.03,0.05,'(a)','Units','normalized','Color','k','FontSize',12)

set(gcf,'position',[100,100,600,450])

% saveas(figure(1),'/home/he/Pictures/paper_2/VT_N2N2.jpg');

saveas(figure(1),'3a_VT_N2N2.jpg');
exportgraphics(figure(1),'3a_VT_N2N2.pdf','BackgroundColor','none','ContentType','vector');

%% Gue19_sfHO
function [rateCoeff,v] = N2N2VTsfHO(Tg,v_str,E_N2v)

% % Tg: gas temperature in K
% % v_str: "v" number in string
% % E_N2v: double array for energy values of N2v0-v58

% identify current V-T reaction by evaluating the vibrational levels (v -> v-1)
v = str2double(v_str);

% evaluate rate coefficient
rateCoeff = v*1e-6*7.8e-12*(Tg)*exp((-218/Tg^(1/3))+690/Tg)*(1-1*exp(-0.288*1.1604505e4/Tg))^(-1);

end

%% Caleb Richards et al 2022 Plasma Sources Sci. Technol. 31 034001
% https://iopscience.iop.org/article/10.1088/1361-6595/ac4de0/pdf
function [rateCoeff,v] = N2N2VT_Richards38(Tg,v_str,E_N2v)

% % Tg: gas temperature in K
% % v_str: "v" number in string
% % E_N2v: double array for energy values of N2v0-v58

% identify current V-T reaction by evaluating the vibrational levels (v -> v-1)
v = str2double(v_str);

% scaling factor
delta_VT = 1.94 / (Tg^(1/3));
s = v * exp(delta_VT*(v-1));

% evaluate rate coefficient
rateCoeff = s * 1e-6 * 3e-4 * exp( -(400 / (Tg^(1/3))) + (886 / (Tg^(2/3))));

end
