clear all, clc, close all

% here we compare the the "sfHO" with the "Gue19 approach" for N-N2 V-T 

addpath ('Gue19')
% load('reactions.mat')
load('species.mat')

figure (1)

% Find internal energy for each species
E_i = str2double(erase(species{2},'eV'));
% N2v1 index in species.csv
N2v1_index = find(strcmp(species{1},'N2v1'));
% N2 energy levels
% V Laporta et al Plasma Sources Sci. Technol. 23 (2014) 065002
% https://iopscience.iop.org/article/10.1088/0963-0252/23/6/065002/pdf
E_N2v = [0; E_i(N2v1_index:N2v1_index+56); 9.748];

Tg = [300 500];
v = 7:57;
v_non = 9:57;
w = 1:57;

rate_k1_f1 = [];
for i =1:length(w)
    [rateCoeff] = N2NVT_Gue19_CapbookK10(Tg(1),string(w(i)),E_N2v);
    rate_k1_f1 = [rate_k1_f1 rateCoeff];
end

rate_k1_f2 = [];
for i =1:length(w)
    [rateCoeff] = N2NVT_Gue19_CapbookK10(Tg(2),string(w(i)),E_N2v);
    rate_k1_f2 = [rate_k1_f2 rateCoeff];
end

rate_k2_f1 = [];
for i =1:length(v)
    [rateCoeff] = N2NVT_Gue19_reactive(Tg(1),string(v(i)),E_N2v);
    rate_k2_f1 = [rate_k2_f1 rateCoeff];
end

rate_k2_f2 = [];
for i =1:length(v)
    [rateCoeff] = N2NVT_Gue19_reactive(Tg(2),string(v(i)),E_N2v);
    rate_k2_f2 = [rate_k2_f2 rateCoeff];
end

rate_k3_f1 = [];
for i =1:length(v_non)
    [rateCoeff] = N2NVT_Gue19_nonReactive(Tg(1),string(v_non(i)),E_N2v);
    rate_k3_f1 = [rate_k3_f1 rateCoeff];
end

rate_k3_f2 = [];
for i =1:length(v_non)
    [rateCoeff] = N2NVT_Gue19_nonReactive(Tg(2),string(v_non(i)),E_N2v);
    rate_k3_f2 = [rate_k3_f2 rateCoeff];
end

plot(w,rate_k1_f1,'k-','LineWidth',2)
hold on
plot(v,rate_k2_f1,'k--','LineWidth',2)
hold on
plot(v_non,rate_k3_f1,'k:','LineWidth',2)
hold on

plot(w,rate_k1_f2,'r-','LineWidth',2)
hold on
plot(v,rate_k2_f2,'r--','LineWidth',2)
hold on
plot(v_non,rate_k3_f2,'r:','LineWidth',2)
hold on

xlim([0 60])
xticks(0:5:60)
xlabel('N_2 vibrational level (v)')

set(gca, 'YScale', 'log')
ylim([1e-30 1e-16])
yticks([1e-30 1e-28 1e-26 1e-24 1e-22 1e-20 1e-18 1e-16])
ylabel('k_{v,w} (m^{3}/s)')

% lgd4 = legend('He {\itet al}','Guerra {\itet al} (reactive)','Guerra {\itet al} (non-reactive)','Location','Southeast')
lgd4 = legend('sfHO','ffQCT (reactive)','ffQCT (non-reactive)','Location','Southeast')
lgd4.FontSize = 15;

set(gca,'FontSize',15)

text(0.05,0.9,'N_2(v) + N(^4S) \rightarrow N_2(w=v-1) + N(^4S) ','Units','normalized','Color',[0 0.5 0],'FontSize',12)
text(0.02,0.53,'500 K','Units','normalized','Color','r','FontSize',12)
text(0.02,0.43,'300 K','Units','normalized','Color','k','FontSize',12)

text(0.03,0.05,'(b)','Units','normalized','Color','k','FontSize',12)

set(gcf,'position',[100,100,600,450])

% saveas(figure(1),'/home/he/Pictures/paper_2/VT_N2N.jpg');

saveas(figure(1),'3b_VT_N2N.jpg');
exportgraphics(figure(1),'3b_VT_N2N.pdf','BackgroundColor','none','ContentType','vector');

%% sfHO N2-N V-T for PaperHeN2O2
function [rateCoeff] = N2NVT_Gue19_CapbookK10(Tg,v_str,E_N2v)

% Tg: gas temperature in K
% v_str: "v" number in string
% E_N2v: double array for energy values of N2v0-v58

% % local copies and definitions of different parameters used in the function
% kb = 1.38064852e-23;
% Lmin = 2e-11;                   % Minimum distance between N2 molecules during V-V collision (m)
% M = 2*14.007*1.660539040e-27;   % Mass of N2 (Kg)
% omega = 4.443e14;               % Harmonic frequency of the oscillator N2 (rad/s)
% chi = 6.073e-3;                 % Anharmonicity of the oscillator N2

% identify current V-T reaction by evaluating the vibrational levels (v -> v-1)
v = str2double(v_str);

rateCoeff =v * 1e-6*4e-10*(Tg/300)^0.5*exp(-(7280/Tg)+(0.065*0.288*1.1604505e4/Tg));

end

%% sfHO N2-N V-T for Guerra view paper (reactive)
function [rateCoeff] = N2NVT_Gue19_reactive(Tg,v_str,E_N2v)

% Tg: gas temperature in K
% v_str: "v" number in string
% E_N2v: double array for energy values of N2v0-v58

% % local copies and definitions of different parameters used in the function
% kb = 1.38064852e-23;
% Lmin = 2e-11;                   % Minimum distance between N2 molecules during V-V collision (m)
% M = 2*14.007*1.660539040e-27;   % Mass of N2 (Kg)
% omega = 4.443e14;               % Harmonic frequency of the oscillator N2 (rad/s)
% chi = 6.073e-3;                 % Anharmonicity of the oscillator N2

% identify current V-T reaction by evaluating the vibrational levels (v -> v-1)
v = str2double(v_str);

A0 = 0.2*2.212*1e4/Tg^1.426;
A1 = 3.210*1e4/Tg^0.8147;
A2 = 2.521*1e5/Tg^1.044;

rateCoeff = 1e-10 * 1e-6 * A0 * exp(-A1/v + A2/v^2);

end

%% sfHO N2-N V-T for Guerra view paper (nonReactive)
function [rateCoeff] = N2NVT_Gue19_nonReactive(Tg,v_str,E_N2v)

% Tg: gas temperature in K
% v_str: "v" number in string
% E_N2v: double array for energy values of N2v0-v58

% % local copies and definitions of different parameters used in the function
% kb = 1.38064852e-23;
% Lmin = 2e-11;                   % Minimum distance between N2 molecules during V-V collision (m)
% M = 2*14.007*1.660539040e-27;   % Mass of N2 (Kg)
% omega = 4.443e14;               % Harmonic frequency of the oscillator N2 (rad/s)
% chi = 6.073e-3;                 % Anharmonicity of the oscillator N2

% identify current V-T reaction by evaluating the vibrational levels (v -> v-1)
v = str2double(v_str);

A0 = 0.2*9.240*1e4/Tg^1.635;
A1 = 1.823*1e4/Tg^0.6984;
A2 = 9.893*1e3/Tg^0.4376;

rateCoeff = 1e-10 * 1e-6 * A0 * exp(-A1/v + A2/v^2);

end
